<?php

switch ($messaggio) {

case "Le date sono sbagliate":                                                           $messaggio = "Das Datum ist falsch"; break;
case "Si deve inserire il tipo di tariffa":                                              $messaggio = "Sie m&uuml;ssen die Preiskategorie angeben"; break;
case "tariffa":                                                                          $messaggio = "Preis"; break;
case "Non è stato ancora inserito il prezzo della":                                     $messaggio = "Sie m&uuml;ssen noch den Preis angeben von"; break;
case "per la settimana dal":                                                             $messaggio = "f&uuml;r die Woche von"; break;
case "per il giorno dal":                                                                $messaggio = "f&uuml;r den Tag von"; break;
case "al":                                                                               $messaggio = "zu"; break;
case "La settimana dal":                                                                 $messaggio = "Die Woche von"; break;
case "Il giorno dal":                                                                    $messaggio = "Der Tag von"; break;
case "è piena":                                                                         $messaggio = "ist ausgebucht"; break;
case "è pieno":                                                                         $messaggio = "ist ausgebucht"; break;
case "Il numero di settimane del costo aggiuntivo settimanale nº":                      $messaggio = "Die Anzahl der Wochen f&uuml;r den w&ouml;chentlichen Zuschlag"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero nº":                         $messaggio = "Die Anzahl der Tage f&uuml;r den t&auml;glichen Zuschlag"; break;
case "supera il numero totale di settimane della prenotazione":                          $messaggio = "ist gr&ouml;&szlig;er als die Anzahl der Wochen f&uuml;r die Reservierung"; break;
case "supera il numero totale di giorni della prenotazione":                             $messaggio = "ist gr&ouml;&szlig;er als die Anzahl der Tage f&uuml;r die Reservierung"; break;
case "persone":                                                                          $messaggio = "Person(en)"; break;
case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":              $messaggio = "Mindestens eine Periode der Zuweisungsregel 1 wird zu beachten sein."; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":                                                                                    $messaggio = "Umbuchungen die im Zeitraum vorgenommen werden mssen <div style=\"display: inline; color: blue;\">Zuordnung zur Regel 1</div>"; break;
case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":                                                                                  $messaggio = "Umbuchungen die im Zeitraum vorgenommen wurden <div style=\"display: inline; color: blue;\">Zuordnung zur Regel 1</div>"; break;
case "La prenotazione dal":                                                              $messaggio = "Die Reservierung vom"; break;
case "a nome di":                                                                        $messaggio = "f&uuml;r Herrn/Frau"; break;
case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":  $messaggio = "Kann nicht fortfahren, weil sie die Reservierungstabelle inzwischen ge&auml;ndert hat."; break;
case "Continua lo stesso":                                                               $messaggio = "Trotzdem fortfahren"; break;
case "Torna indietro":                                                                   $messaggio = "zur&uuml;ck"; break;
case "Non esistono clienti chiamati":                                                    $messaggio = "Es gibt keine Kunden mit Namen"; break;
case "nel database":                                                                     $messaggio = "in der Datenbank"; break;
case "Inserisci i dati di un nuovo cliente":                                             $messaggio = "Neuen Kunden anlegen"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":                       $messaggio = "Es gibt bereits folgende Kunden mit dem gleichen oder &auml;hnlichen Nachnamen"; break;
case "Esistono i seguenti clienti con un cognome e nome uguale o simile":                $messaggio = "Es gibt bereits folgende Kunden mit dem gleichen oder &auml;hnlichen Vor- und Nachnamen"; break;
case "nato il":                                                                          $messaggio = "geboren am"; break;
case "nata il":                                                                          $messaggio = "geboren am"; break;
case "CAP":                                                                              $messaggio = "Postleitzahl"; break;
case "Telefono":                                                                         $messaggio = "Telefonnummer"; break;
case "2º telefono":                                                                     $messaggio = "Mobiltelefon"; break;
case "3º telefono":                                                                     $messaggio = "weitere Telefonnummer/Faxnummer"; break;
case "Utilizza il cliente":                                                              $messaggio = "Verwende Kunde"; break;
case "per la prenotazione":                                                              $messaggio = "f&uuml;r die Reservierung"; break;
case "Modifica i dati del cliente":                                                      $messaggio = "Daten &auml;ndern von Kunde"; break;
case "Inserisci un nuovo cliente":                                                       $messaggio = "Neuen Kunden anlegen"; break;
case "I dati del cliente":                                                               $messaggio = "Gastdaten"; break;
case "sono stati inseriti":                                                              $messaggio = "wurden eingetragen"; break;
case "Inserisci o modifica i dati di un cliente":                                        $messaggio = "G&auml;ste erfassen"; break;
case "Cognome":                                                                          $messaggio = "Nachname"; break;
case "nome":                                                                             $messaggio = "Vorname"; break;
case "sesso":                                                                            $messaggio = "Geschlecht"; break;
case "Data di nascita":                                                                  $messaggio = "Geburtsdatum"; break;
case "anno con 4 cifre":                                                                 $messaggio = "Jahr (4stellig)"; break;
case "Nazione":                                                                          $messaggio = "Staatsangeh&ouml;rigkeit"; break;
case "città":                                                                           $messaggio = "Ort"; break;
case "Via":                                                                              $messaggio = "Stra&szlig;e"; break;
case "Piazza":                                                                           $messaggio = "Platz"; break;
case "Viale":                                                                            $messaggio = "Allee"; break;
case "Piazzale":                                                                         $messaggio = "Weg"; break;
case "Vicolo":                                                                           $messaggio = "Nr."; break;
case "Numero di telefono":                                                               $messaggio = "Telefonnummer"; break;
case "Secondo telefono":                                                                 $messaggio = "Mobiltelefonnummer"; break;
case "Terzo telefono":                                                                   $messaggio = "weitere Telefonnummer/Faxnummer"; break;
case "Numero di fax":                                                                    $messaggio = "Faxnummer"; break;
case "Seconda persona di riferimento":                                                   $messaggio = "2. Kontaktperson"; break;
case "Inserisci i dati":                                                                 $messaggio = "speichern der Daten"; break;
case "Torna al menù principale":                                                        $messaggio = "Zur&uuml;ck zum Hauptmen&uuml;"; break;
case "Italia":                                                                           $messaggio = "Italien"; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":           $messaggio = "Daten der 2. Kontaktperson werden nicht ge&auml;ndert"; break;
case "sono stati modificati":                                                            $messaggio = "wurde ge&auml;ndert"; break;
case "e":                                                                                $messaggio = "und"; break;
case "Il numero di prenotazioni è sbagliato":                                           $messaggio = "Die Anzahl der Reservierungen ist falsch"; break;
case "Aggiungi":                                                                         $messaggio = "Hinzuf&uuml;gen"; break;
case "Nº di tipologie da aggiungere":                                                   $messaggio = "Anzahl der Buchungsmasken, die hinzugef&uuml;gt werden sollen"; break;
case "Non si è trovato nessun cliente chiamato":                                        $messaggio = "Es gibt keine Kunden mit Namen"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":                          $messaggio = "Es gibt keine Zeitr&auml;ume in Zuweisungsregel 1 die erlauben, die Reservierung einzutragen f&uuml;r den Kunden"; break;
case "Il numero di persone è sbagliato":                                                $messaggio = "Die Anzahl der Personen ist falsch"; break;
case "I dati di un costo aggiuntivo sono errati":                                        $messaggio = "Daten eines Zuschlags sind falsch"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":                      $messaggio = "Es kann nur ein prozentualer Zuschlag auf dem Gesamtbetrag je Reservierung angelegt werden"; break;
case "Non si puo inserire il costo aggiuntivo":                                          $messaggio = "Der Zuschlag"; break;
case "in questo periodo":                                                                $messaggio = "kann in diesem Zeitraum nicht eingef&uuml;t werden"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":                      $messaggio = "W&auml;hlen Sie die Wochen, in denen Zuschl&auml;ge angewendet werden sollen"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":                          $messaggio = "W&auml;hlen Sie die Tage, in denen Zuschl&auml;ge angewendet werden sollen"; break;
case "Continua":                                                                         $messaggio = "Weiter"; break;
case "Non si possono inserire altri costi":                                              $messaggio = "Sie k&ouml;nnen keine weiteren Zuschl&auml;ge eingeben"; break;
case "in questo periodo, già":                                                          $messaggio = "bereits in diesem Zeitraum"; break;
case "presenti":                                                                         $messaggio = "vorhanden"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":                 $messaggio = "F&uuml;r den Zuschlag muss die Anzahl der Personen angegeben werden"; break;
case "Il costo aggiuntivo":                                                              $messaggio = "Der Zuschlag"; break;
case "è incompatibile con la tariffa selezionata":                                      $messaggio = "ist mit dem gew&auml;hlten Tarif nicht kompatibel"; break;
case "non può essere applicato":                                                        $messaggio = "kann nicht angewendet werden"; break;
case "regione":                                                                          $messaggio = "Region"; break;
case "Documento":                                                                        $messaggio = "Ausweisdokument"; break;
case "scadenza":                                                                         $messaggio = "g&uuml;ltig bis"; break;
case "Torna all'inserimento clienti":                                                    $messaggio = "Zur&uuml;ck zum Einf&uuml;gen von Kunden"; break;
case "Annulla":                                                                          $messaggio = "Abbrechen"; break;
case "Ospite della prenotazione":                                                        $messaggio = "G&auml;ste zur Buchung"; break;
case "tipologia":                                                                        $messaggio = "Kategorie"; break;
case "Ospiti della prenotazione":                                                        $messaggio = "G&auml;ste zur Buchung"; break;
case "Altri ospiti":                                                                     $messaggio = "Andere G&auml;ste"; break;
case "nato":                                                                             $messaggio = "geboren am"; break;
case "nata":                                                                             $messaggio = "geboren am"; break;
case "il":                                                                               $messaggio = "am"; break;
case " a":                                                                               $messaggio = " in"; break;
case "scade":                                                                            $messaggio = "l&auml;ft ab am"; break;
case "cittadinanza":                                                                     $messaggio = "Staatsangeh&ouml;rigkeit"; break;
case "città di nascita":                                                                $messaggio = "Geburtsort"; break;
case "reg./prov. di nascita":                                                            $messaggio = "Geburtsregion"; break;
case "nazione di nascita":                                                               $messaggio = "Geburtsland"; break;
case "Residenza":                                                                        $messaggio = "Wohnort"; break;
case "reg./prov.":                                                                       $messaggio = "Bezirk/Region"; break;
case "nazione":                                                                          $messaggio = "Staat"; break;
case "rilasciato da":                                                                    $messaggio = "ausgestellt von"; break;
case "nazione di rilascio":                                                              $messaggio = "ausstellender Staat"; break;
case "parentela":                                                                        $messaggio = "Verwandtschaftsgrad"; break;
case "Codice fiscale":                                                                   $messaggio = "Steuernummer"; break;
case "con i costi aggiuntivi selezionati":                                               $messaggio = "mit den ausgewhlten Mehrkosten"; break;
case "I beni richiesti dal costo":                                                       $messaggio = "Kosten des Artikels erforderlich"; break;
case "non sono disponibili nell'inventario":                                             $messaggio = "sind nicht aus dem Bestand verfgbar"; break;
case "Si deve inserire il numero delle persone per questa tariffa":                      $messaggio = "Die Eingabe der Anzahl der Gste ist erforderlich"; break;
case "Partita iva":                                                                      $messaggio = "UStID."; break;
case "lo sconto è sbagliato":                                                           $messaggio = "der Rabattsatz ist falsch"; break;
case "la caparra è sbagliata":                                                          $messaggio = "die Anzahlung ist falsch"; break;
case "soprannome":                                                                       $messaggio = "Nickname"; break;
case "le commissioni sono sbagliate":                                                    $messaggio = "die Provisionen sind falsch"; break;
case "lingua":  				                                         $messaggio = "Sprache"; break;
case "ln.":  					                                         $messaggio = "ln."; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "The client's surname is needed"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "The requested rate is closed in this period"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>